pub struct HarnessConfig { /* private fields */ }Expand description
Configuration checked before an actor exists. A zero step limit or a zero model attempt count cannot construct a harness.
Implementations
Sourceimpl HarnessConfig
impl HarnessConfig
pub fn new( budget: u32, compact_after_chars: usize, step_limit: u32, model_attempts: u32, system: Vec<String>, tools: Vec<ToolSpec>, ) -> Result<Self, ActorError>
Sourcepub fn with_tool_round_cap(self, cap: u32) -> Self
pub fn with_tool_round_cap(self, cap: u32) -> Self
One later completion sees no tools once this many tool results exist. The caller does not inject a user message to force that completion.
pub fn step_limit(&self) -> u32
pub fn budget(&self) -> u32
pub fn compact_after_chars(&self) -> usize
pub fn model_attempts(&self) -> u32
pub fn system(&self) -> &[String]
pub fn tools(&self) -> &[ToolSpec]
pub fn tool_round_cap(&self) -> Option<u32>